@@ -221,7 +221,7 @@ void hash_show(hash_obj* self, char* fname)
    int i;
    int max;
    hash_it* it;
-   strncpy(tmp, "", 4096);
+   xstrncpy(tmp, "", 4096);
    
    max = self->mTableSize;
    for(i=0; i<max; i++) {
@@ -233,7 +233,7 @@ void hash_show(hash_obj* self, char* fname)
          it = it->mCollisionIt;
       }
     
-    strncat(tmp, "\n", 4096);
+    xstrncat(tmp, "\n", 4096);
    }
     
     FILE* f = fopen(fname, "w");
